==> gcc-3.2.3.tar.bz2: gcc-3.2.3/libjava/java/awt/ItemSelectable.java <==
/* ItemSelectable.java -- Items that can be selected
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt;

import java.awt.event.ItemListener;

/**
  * This interface is for objects that can have one or more items
  * selected.  For example, radio buttons.
  *
  * @author Aaron M. Renn (arenn@urbanophile.com)
  */
public interface ItemSelectable
{

/**
  * Returns the list of objects that are selected in this component.
  *
  * @return The list of objects that are selected, or <code>null</code> if
  * no objects are selected.
  */
public abstract Object[]
getSelectedObjects();

/*************************************************************************/

/**
  * Adds an item listener to this object.  It will receive
  * selection events for this object.
  *
  * @param listener The item listener to add.
  */
public abstract void
addItemListener(ItemListener listener);

/*************************************************************************/

/**
  * Removes an item listener from this object.  It will no longer receive
  * selection change events.
  *
  * @param listener The item listener to remove.
  */
public abstract void
removeItemListener(ItemListener listener);

} // interface ItemSelectable

==> gcc-4.0.1.tar.bz2: gcc-4.0.1/libjava/java/awt/ItemSelectable.java <==
/* ItemSelectable.java -- items that can be selected
   Copyright (C) 1999, 2002, 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt;

import java.awt.event.ItemListener;

/**
 * This interface is for objects that can have one or more items selected.
 * For example, radio buttons.
 *
 * @author Aaron M. Renn (arenn@urbanophile.com)
 * @since 1.0
 * @status updated to 1.4
 */
public interface ItemSelectable
{
  /**
   * Returns the list of objects that are selected in this component.
   *
   * @return the list of selected objects, or null
   */
  Object[] getSelectedObjects();

  /**
   * Adds an item listener to this object.  It will receive selection events
   * for this object by the user (but not programatically). If listener is
   * null, it is ignored.
   *
   * @param listener the item listener to add
   */
  void addItemListener(ItemListener listener);

  /**
   * Removes an item listener from this object.
   *
   * @param listener the item listener to remove
   */
  void removeItemListener(ItemListener listener);
} // interface ItemSelectable
